@@ -9,6 +9,8 @@ from pandas.api.types import (
     is_object_dtype,
 )
 
+from profiling.utils import vega_sanitize
+
 
 def condexp(func, X, y, var):
     """Plot conditional expectations"""
@@ -56,16 +58,19 @@ def condexp_num(func, X, y, var, n_cut=10):
     )
 
     df = df_pred.append(df_act, ignore_index=True)
+
+    # Create plot
+    var_sanitized = vega_sanitize(var, datatype="Q")
     chart = (
         alt.Chart(df)
         .mark_line(point=True)
         .encode(
-            x=alt.X(var, scale=alt.Scale(zero=False)),
+            x=alt.X(var_sanitized, scale=alt.Scale(zero=False)),
             y=alt.Y(y.name, scale=alt.Scale(zero=False)),
             color="Type:N",
             tooltip=[
                 "Type:N",
-                alt.Tooltip(f"{var}:Q", format=".2f"),
+                alt.Tooltip(var_sanitized, format=".2f"),
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
         )
@@ -111,14 +116,23 @@ def condexp_cat(func, X, y, var, n_max=25):
     )
     df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(Type="Actual Value")
 
+    # Create plot
+    var_sanitized = vega_sanitize(var, datatype="N")
+
     chart_pred = (
         alt.Chart(df_pred)
         .mark_circle(opacity=0.9)
         .encode(
             x=alt.X(y.name, scale=alt.Scale(zero=False)),
-            y=alt.Y(var, sort=ordered_categories, scale=alt.Scale(zero=False)),
+            y=alt.Y(
+                var_sanitized, sort=ordered_categories, scale=alt.Scale(zero=False),
+            ),
             color="Type:N",
-            tooltip=["Type:N", var, alt.Tooltip(f"{y.name}:Q", format=".2f")],
+            tooltip=[
+                "Type:N",
+                var_sanitized,
+                alt.Tooltip(f"{y.name}:Q", format=".2f"),
+            ],
         )
         .interactive()
     )
@@ -128,9 +142,13 @@ def condexp_cat(func, X, y, var, n_max=25):
         .mark_circle(opacity=0.9)
         .encode(
             x=alt.X(y.name, scale=alt.Scale(zero=False)),
-            y=alt.Y(var, sort=ordered_categories),
+            y=alt.Y(var_sanitized, sort=ordered_categories),
             color="Type:N",
-            tooltip=["Type:N", var, alt.Tooltip(f"{y.name}:Q", format=".2f")],
+            tooltip=[
+                "Type:N",
+                var_sanitized,
+                alt.Tooltip(f"{y.name}:Q", format=".2f"),
+            ],
         )
         .interactive()
     )
@@ -170,16 +188,20 @@ def condexp_datetime(func, X, y, var, n_max=100):
     df_act = df_agg.rename(columns={"Actual Value": y.name}).assign(Type="Actual Value")
 
     df = df_pred.append(df_act, ignore_index=True)
+
+    # Create plot
+    var_sanitized = vega_sanitize(var, datatype="T")
+
     chart = (
         alt.Chart(df)
         .mark_line(point=True)
         .encode(
-            x=var,
+            x=var_sanitized,
             y=alt.Y(y.name, scale=alt.Scale(zero=False)),
             color="Type:N",
             tooltip=[
                 "Type:N",
-                alt.Tooltip(f"{var}:Q", format=".2f"),
+                alt.Tooltip(var_sanitized, format=".2f"),
                 alt.Tooltip(f"{y.name}:Q", format=".2f"),
             ],
         )
