@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 import pytest
 
-from profiling.shap import ShapExplainer, comb, n_choose_k
+from profiling.shap import ShapExplainer, comb, n_choose_k, reduce_func, update_columns
 
 
 @pytest.mark.parametrize("n_cols", [1, 2, 3, 4])
@@ -45,9 +45,10 @@ def test_coefficient_recovery(coef):
 def test_large_df():
     """Test that SHAP runs smoothly on large dataframes"""
     np.random.seed(1986)
-    n_col = 100
+    n_col = 10
+    n_row = 10000
     coef = np.random.randn(n_col)
-    X = pd.DataFrame(np.zeros((1000000, n_col)))
+    X = pd.DataFrame(np.zeros((n_row, n_col)))
     intercept = 5.23
 
     def func(X):
@@ -203,3 +204,73 @@ def test_axioms():
     # consistency
     assert np.all(shap0[0] < shap1[0])
     assert np.all(shap0 < shap1 + 1e-9)
+
+
+def test_profile_columns():
+    """Test Shapley value calculation for a subset of columns"""
+    np.random.seed(1986)
+    n_col = 10
+    n_row = 1000
+    coef = np.random.randn(n_col)
+    X = pd.DataFrame(np.zeros(shape=(n_row, n_col)))
+    intercept = 5.23
+
+    def func(X):
+        return X.values @ coef + intercept
+
+    profile_columns = X.columns[:-1]
+    shap_explainer = ShapExplainer(func, X, profile_columns=profile_columns)
+    test_row = pd.DataFrame(
+        np.ones(shape=(1, len(profile_columns))), columns=profile_columns
+    )
+    ref, shap = shap_explainer.explain(test_row)
+    assert np.allclose(ref, intercept)  # reference
+    assert np.allclose(shap, coef[:-1])  # shapley values
+    assert np.allclose(
+        ref + shap.sum(axis=1), shap_explainer.func(test_row)
+    )  # bookkeeping
+
+
+def test_update_columns():
+    # base case
+    base = pd.DataFrame({"a": [1]})
+    update = pd.DataFrame({"a": [2]})
+    expected = pd.DataFrame({"a": [2]})
+    result = update_columns(base, update)
+    assert result.equals(expected)
+
+    # broadcasting
+    base = pd.DataFrame({"a": [1], "b": [True]})
+    update = pd.DataFrame({"a": [2, 3]})
+    expected = pd.DataFrame({"a": [2, 3], "b": [True, True]})
+    result = update_columns(base, update)
+    assert result.equals(expected)
+
+    # index mismatch handled gracefully
+    base = pd.DataFrame({"a": [1], "b": [True]}, index=[0])
+    update = pd.DataFrame({"a": [2, 3]}, index=[1, 2])
+    expected = pd.DataFrame({"a": [2, 3], "b": [True, True]}, index=[1, 2])
+    result = update_columns(base, update)
+    assert result.equals(expected)
+
+    # column mismatch
+    with pytest.raises(KeyError):
+        base = pd.DataFrame({"a": [1]})
+        update = pd.DataFrame({"b": [2, 3]})
+        result = update_columns(base, update)
+
+
+def test_reduce_func():
+    X_orig = pd.DataFrame({"a": [1, 2], "b": [3, 4]})
+    X_subset = X_orig.drop(columns=["a"])
+
+    def predict(X):
+        assert list(X.columns) == ["a", "b"]
+        return [0] * len(X)
+
+    with pytest.raises(AssertionError):
+        predict(X_subset)
+
+    predict_subset = reduce_func(func=predict, X=X_orig)
+    pred = predict_subset(X_subset)
+    assert pred == [0, 0]
